/*
 *  Copyright 2015 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

/**
 * The ODF catalog DAO.
 */
 Ext.define('Ametys.odf.program.ProgramDAO', {
 	singleton: true,
 	
 	constructor: function(config)
 	{
		/**
		 * @callable
		 * @member Ametys.odf.program.ProgramDAO
		 * @method translateProgram 
		 * This calls the method 'translateProgram' of the server DAO 'ProgramDAO'.
         * Translates a given program in a language
		 * @param {Object[]} parameters The parameters to transmit to the server method
		 * @param {String} parameters.contentId The content id
 		 * @param {String} parameters.language The target language
 		 * @param {Boolean} parameters.full True if full copy
		 * @param {Function} callback The function to call when the java process is over. Use options.scope for the scope. 
		 * @param {Object} callback.returnedValue The value return from the server. Null on error (please note that when an error occured, the callback may not be called depending on the value of errorMessage).
		 * @param {Object} callback.arguments Other arguments specified in option.arguments                 
		 * @param {Object} [options] Advanced options for the call.
		 * @param {Boolean/String/Object} [options.errorMessage] Display an error message. See Ametys.data.ServerComm#callMethod errorMessage.
		 * @param {Boolean/String/Object} [options.waitMessage] Display a waiting message. See Ametys.data.ServerComm#callMethod waitMessage.
		 * @param {Number} [options.scope] This parameter is the scope used to call the callback. Moreover is the given class is a mixin of Ametys.data.ServerCaller, its methods Ametys.data.ServerCaller#beforeServerCall and Ametys.data.ServerCaller#afterServerCall will be used so see their documentation to look for additional options (such a refreshing on Ametys.ribbon.element.ui.ButtonController#beforeServerCall).
		 * @param {Number} [options.priority] The message priority. See Ametys.data.ServerComm#callMethod for more information on the priority. PRIORITY_SYNCHRONOUS cannot be used here.
		 * @param {String} [options.cancelCode] Cancel similar unachieved read operations. See Ametys.data.ServerComm#callMethod cancelCode.
		 * @param {Object} [options.arguments] Additional arguments set in the callback.arguments parameter.                  
		 * @param {Boolean} [options.ignoreCallbackOnError] If the server throws an exception, should the callback beeing called with a null parameter. See Ametys.data.ServerComm#callMethod ignoreOnError.
		 */
		this.addCallables(
			{
			    role: "org.ametys.odf.program.ProgramDAO",
				methodName: "translateProgram",
	     		callback: {
	         		handler: this._translateProgramCb
	     		},
                waitMessage: "{{i18n PLUGINS_ODF_UITOOL_TRANSLATE_WAITING_MESSAGE}}",
				errorMessage: {
				    msg: "{{i18n PLUGINS_ODF_UITOOL_TRANSLATE_ERROR}}",
				    category: Ext.getClassName(this)
				}
			}
		);
 	},
 	
 	/**
 	 * Callback function called after {@link #translateProgram} has been processed.
 	 * @param {Object} response The text response provided by the {@link Ametys.data.ServerComm}
 	 * @private
 	 */
 	_translateProgramCb: function(response)
 	{
		var error = response['error'];
		if (error == 'already-exist')
		{
			Ametys.Msg.show({
				title: "{{i18n PLUGINS_ODF_UITOOL_TRANSLATE_TITLE}}",
				msg: "{{i18n PLUGINS_ODF_UITOOL_TRANSLATE_ALREADY_EXIST}}",
				buttons: Ext.Msg.OK,
				icon: Ext.MessageBox.INFO
			});
		}
		else if (error == 'same-language')
		{
			Ametys.Msg.show({
				title: "{{i18n PLUGINS_ODF_UITOOL_TRANSLATE_TITLE}}",
				msg: "{{i18n PLUGINS_ODF_UITOOL_TRANSLATE_ERROR_SAME_LANGUAGE}}",
				buttons: Ext.Msg.OK,
				icon: Ext.MessageBox.ERROR
			});
		}
		else if (error == null)
		{
	    	Ametys.Msg.show({
                title: "{{i18n PLUGINS_ODF_UITOOL_TRANSLATE_TITLE}}",
                msg: "{{i18n PLUGINS_ODF_UITOOL_TRANSLATE_SUCCESS}}",
                buttons: Ext.Msg.OK,
                icon: Ext.MessageBox.INFO
            });
		}
 	}
 	
 });