/*
 *  Copyright 2018 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.odf.catalog;

import java.util.Map;

import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.apache.avalon.framework.service.Serviceable;

import org.ametys.odf.course.Course;
import org.ametys.odf.coursepart.CoursePart;
import org.ametys.odf.program.Program;
import org.ametys.plugins.repository.AmetysObjectResolver;
import org.ametys.runtime.plugin.component.AbstractLogEnabled;

/**
 * Copy updater to update the course holder on a {@link CoursePart}.
 */
public class CoursePartHolderUpdater extends AbstractLogEnabled implements CopyCatalogUpdater, Serviceable
{
    private AmetysObjectResolver _resolver;
    
    @Override
    public void service(ServiceManager manager) throws ServiceException
    {
        _resolver = (AmetysObjectResolver) manager.lookup(AmetysObjectResolver.ROLE);
    }
    
    @Override
    public void updateContent(String initialCatalogName, String newCatalogName, Program initialProgram, Program createdProgram)
    {
        // Nothing to do
    }

    @Override
    public void updateContents(String initialCatalogName, String newCatalogName, Map<String, String> copiedPrograms, Map<String, String> copiedSubPrograms, Map<String, String> copiedContainers, Map<String, String> copiedCourseLists, Map<String, String> copiedCourses, Map<String, String> copiedCourseParts)
    {
        for (String copiedCoursePartId : copiedCourseParts.values())
        {
            CoursePart copiedCoursePart = _resolver.resolveById(copiedCoursePartId);
            if (copiedCoursePart == null)
            {
                getLogger().warn("There is no course part with the identifier '{}'.", copiedCoursePartId);
            }
            else
            {
                Course courseHolder = copiedCoursePart.getCourseHolder();
                if (courseHolder == null)
                {
                    getLogger().warn("The course part '{}' of the catalog '{}' haven't any course holder.", copiedCoursePart.getTitle(), copiedCoursePart.getCatalog());
                }
                else
                {
                    String copiedCourseHolder = copiedCourses.get(courseHolder.getId());
                    if (copiedCourseHolder == null)
                    {
                        getLogger().warn("The course part '{}' of the catalog '{}' can't get the corresponding course holder with the identifier '{}'.", copiedCoursePart.getTitle(), copiedCoursePart.getCatalog(), courseHolder.getId());
                    }
                    else
                    {
                        copiedCoursePart.setValue(CoursePart.COURSE_HOLDER, copiedCourseHolder);
                        copiedCoursePart.saveChanges();
                    }
                }
            }
        }
    }
}
