/*
 *  Copyright 2019 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.odf.catalog;

import java.util.Map;

import org.ametys.cms.repository.ModifiableContent;
import org.ametys.odf.ProgramItem;
import org.ametys.odf.program.Program;

/**
 * The catalog copy updater to remove the education booklets
 */
public class EducationalBookletCopyUpdater extends AbstractProgramItemAttributeCopyUpdater
{
    @Override
    public void updateContent(String initialCatalogName, String newCatalogName, Program initialProgram, Program createdProgram)
    {
        // Nothing to do
    }

    @Override
    public void updateContents(String initialCatalogName, String newCatalogName, Map<String, String> copiedPrograms, Map<String, String> copiedSubPrograms,
            Map<String, String> copiedContainers, Map<String, String> copiedCourseLists, Map<String, String> copiedCourses, Map<String, String> copiedCourseParts)
    {
        for (String subProgramId : copiedSubPrograms.values())
        {
            ModifiableContent content = _ametysResolver.resolveById(subProgramId);
            content.removeValue(ProgramItem.EDUCATIONAL_BOOKLETS);
            
            if (content.needsSave())
            {
                content.saveChanges();
            }
        }
    }
}
