/*
 *  Copyright 2017 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.odf.catalog;

import java.util.HashMap;
import java.util.Map;

import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;
import org.apache.avalon.framework.service.Serviceable;

import org.ametys.cms.repository.Content;
import org.ametys.cms.repository.ModifiableContent;
import org.ametys.odf.program.Program;
import org.ametys.odf.translation.TranslationHelper;
import org.ametys.plugins.repository.AmetysObjectResolver;

/**
 * This updater updates the translations of created contents after the full catalog copy
 *
 */
public class TranslationUpdater implements CopyCatalogUpdater, Serviceable
{
    private AmetysObjectResolver _resolver;
    
    @Override
    public void service(ServiceManager manager) throws ServiceException
    {
        _resolver = (AmetysObjectResolver) manager.lookup(AmetysObjectResolver.ROLE);
    }

    @Override
    public void updateContent(String initialCatalogName, String newCatalogName, Program initalContent, Program createdContent)
    {
        // Nothing to do
    }
    
    @Override
    public void updateContents(String initialCatalogName, String newCatalogName, Map<String, String> copiedPrograms, Map<String, String> copiedSubPrograms, Map<String, String> copiedContainers, Map<String, String> copiedCourseLists, Map<String, String> copiedCourses, Map<String, String> copiedCourseParts)
    {
        _setTranslations(copiedPrograms);
        _setTranslations(copiedContainers);
        _setTranslations(copiedSubPrograms);
        _setTranslations(copiedCourseLists);
        _setTranslations(copiedCourses);
        _setTranslations(copiedCourseParts);
    }

    /**
     * Set the translations
     * @param copiedContents Contents to update
     */
    protected void _setTranslations(Map<String, String> copiedContents)
    {
        for (String initialContentId : copiedContents.keySet())
        {
            // Get the translations of initial content
            Content initialContent = _resolver.resolveById(initialContentId);
            Map<String, String> translations = TranslationHelper.getTranslations(initialContent);
            
            if (!translations.isEmpty())
            {
                Map<String, String> updatedTranslations = new HashMap<>();
                
                for (String lang : translations.keySet())
                {
                    // For each translation, get its copy in the new catalog
                    String translatedContentId = translations.get(lang);
                    if (copiedContents.containsKey(translatedContentId))
                    {
                        updatedTranslations.put(lang, copiedContents.get(translatedContentId));
                    }
                }
                
                // Update the translations for created content
                ModifiableContent createdContent = _resolver.resolveById(copiedContents.get(initialContentId));
                TranslationHelper.setTranslations(createdContent, updatedTranslations);
            }
        }
    }
}
