/*
 *  Copyright 2017 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.odf.clientsideelement;

import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;

import org.apache.avalon.framework.service.ServiceException;
import org.apache.avalon.framework.service.ServiceManager;

import org.ametys.cms.repository.Content;
import org.ametys.cms.repository.WorkflowAwareContent;
import org.ametys.odf.ODFHelper;
import org.ametys.odf.ProgramItem;
import org.ametys.runtime.i18n.I18nizableText;

/**
 * Set the attribute of type 'content' of a content, with another content.
 * If content is a {@link ProgramItem}, additional check will be done on catalog and content language
 */
public class SetContentAttributeClientSideElement extends org.ametys.cms.clientsideelement.relations.SetContentAttributeClientSideElement
{
    /** The ODF helper */
    protected ODFHelper _odfHelper;
    
    @Override
    public void service(ServiceManager manager) throws ServiceException
    {
        super.service(manager);
        _odfHelper = (ODFHelper) manager.lookup(ODFHelper.ROLE);
    }
    
    @Override
    protected Map<WorkflowAwareContent, Integer> _filterContentsToEdit(Map<WorkflowAwareContent, Integer> contentsToEdit, List<String> contentIdsToReference, List<I18nizableText> errorMessages, List<String> errorIds, Map<String, Object> additionalParams)
    {
        Map<WorkflowAwareContent, Integer> validContents = new LinkedHashMap<>();
        Map<WorkflowAwareContent, Integer> filteredContents = super._filterContentsToEdit(contentsToEdit, contentIdsToReference, errorMessages, errorIds, additionalParams);
        
        @SuppressWarnings("unchecked")
        List<Content> refContents = (List<Content>) _resolve(contentIdsToReference);
        
        for (Map.Entry<WorkflowAwareContent, Integer> contentEntry : filteredContents.entrySet())
        {
            WorkflowAwareContent content = contentEntry.getKey();
            
            for (Content refContent : refContents)
            {
                if (!_odfHelper.isRelationCompatible(refContent, content, errorMessages, additionalParams))
                {
                    errorIds.add(content.getId());
                }
                else
                {
                    validContents.put(content, contentEntry.getValue());
                }
            }
        }
        
        return validContents;
    }
    
}
