/*
 *  Copyright 2011 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.ametys.odf.workflow;

import java.util.List;
import java.util.Map;
import java.util.Optional;
import java.util.function.Function;

import org.apache.commons.lang3.StringUtils;

import org.ametys.cms.repository.ModifiableContent;
import org.ametys.cms.workflow.CreateContentFunction;
import org.ametys.cms.workflow.EditContentFunction;
import org.ametys.odf.ProgramItem;

import com.opensymphony.workflow.WorkflowException;

/**
 * Abstract OSWorkflow function for creating a {@link ProgramItem} content
 * Populate catalog and code metadata.
 */
public abstract class AbstractCreateODFProgramItemFunction extends AbstractCreateODFContentFunction
{
    @SuppressWarnings("unchecked")
    @Override
    protected void _populateAdditionalData(Map transientVars, ModifiableContent content) throws WorkflowException
    {
        super._populateAdditionalData(transientVars, content);
        
        if (content instanceof ProgramItem)
        {
            Optional<String> catalog = Optional.ofNullable(transientVars.get(CONTENT_CATALOG_KEY))
                    .map(String.class::cast)
                    .filter(StringUtils::isNotEmpty);
            
            if (!catalog.isPresent())
            {
                // Use typed values from the EditContentFunction
                catalog = Optional.ofNullable(getContextParameters(transientVars))
                        .map(params -> params.get(EditContentFunction.VALUES_KEY))
                        .map(Map.class::cast)
                        .map(values -> values.get(ProgramItem.CATALOG))
                        .map(String.class::cast)
                        .filter(StringUtils::isNotEmpty);
            }

            if (!catalog.isPresent())
            {
                // Use raw values from the EditContentFunction
                catalog = Optional.ofNullable(getContextParameters(transientVars))
                        .map(params -> params.get(EditContentFunction.FORM_RAW_VALUES))
                        .map(Map.class::cast)
                        .map(rawValues -> rawValues.get(EditContentFunction.FORM_ELEMENTS_PREFIX + ProgramItem.CATALOG))
                        .map(String.class::cast)
                        .filter(StringUtils::isNotEmpty);
            }
            
            // Used to get the catalog if the program item is created by java code, like for the csv import.
            if (!catalog.isPresent())
            {
                catalog = Optional.ofNullable(transientVars.get(CreateContentFunction.INITIAL_VALUE_SUPPLIER))
                        .map(Function.class::cast)
                        .map(function -> function.apply(List.of(ProgramItem.CATALOG)))
                        .map(String.class::cast)
                        .filter(StringUtils::isNotEmpty);
            }
            
            catalog.ifPresent(c -> ((ProgramItem) content).setCatalog(c));
        }
        
        String code = content.getValue(ProgramItem.CODE);
        if (org.apache.commons.lang.StringUtils.isEmpty(code))
        {
            content.setValue(ProgramItem.CODE, org.ametys.core.util.StringUtils.generateKey().toUpperCase());
        }
    }

}
